summaryrefslogtreecommitdiff
path: root/internal/models/timeline.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/models/timeline.go')
-rw-r--r--internal/models/timeline.go17
1 files changed, 11 insertions, 6 deletions
diff --git a/internal/models/timeline.go b/internal/models/timeline.go
index 54f7f45..3475696 100644
--- a/internal/models/timeline.go
+++ b/internal/models/timeline.go
@@ -1,6 +1,10 @@
package models
-import "time"
+import (
+ "time"
+
+ "task-dashboard/internal/config"
+)
type TimelineItemType string
@@ -37,15 +41,16 @@ type TimelineItem struct {
// ComputeDaySection sets the DaySection based on the item's time
func (item *TimelineItem) ComputeDaySection(now time.Time) {
- // Ensure we're working in local timezone for consistent comparisons
- localNow := now.Local()
- localItemTime := item.Time.Local()
+ // Use configured display timezone for consistent comparisons
+ tz := config.GetDisplayTimezone()
+ localNow := now.In(tz)
+ localItemTime := item.Time.In(tz)
- today := time.Date(localNow.Year(), localNow.Month(), localNow.Day(), 0, 0, 0, 0, time.Local)
+ today := time.Date(localNow.Year(), localNow.Month(), localNow.Day(), 0, 0, 0, 0, tz)
tomorrow := today.AddDate(0, 0, 1)
dayAfterTomorrow := today.AddDate(0, 0, 2)
- itemDay := time.Date(localItemTime.Year(), localItemTime.Month(), localItemTime.Day(), 0, 0, 0, 0, time.Local)
+ itemDay := time.Date(localItemTime.Year(), localItemTime.Month(), localItemTime.Day(), 0, 0, 0, 0, tz)
if itemDay.Before(tomorrow) {
item.DaySection = DaySectionToday